@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2002, 2003 Philip Blundell <philb@gnu.org>
+ * Copyright (C) 2005 Philippe De Swert <philippedeswert@scarlet.be>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,8 +26,6 @@
 #define _(_x) gettext(_x)
 #define JOURNAL_FILE "/tmp/journal.html"
 
-static const guint window_x = 240, window_y = 320;
-
 struct gpe_icon my_icons[] = {
   { "clock", },
   { "stop_clock", },
@@ -270,7 +269,7 @@ stop_timing (GtkWidget *w, gpointer user_data)
       struct task *t;
       gchar *text = " ";
       t = gtk_ctree_node_get_row_data (ct, node);
-/*      if (confirm_dialog (&text, _("Clocking out:"), t->description))*/
+      if (confirm_dialog (&text, _("Clocking out:"), t->description))
 	{
 	  gtk_ctree_node_set_text (ct, node, 1, "");
 	  log_entry (STOP, time (NULL), t, text);
@@ -420,7 +419,7 @@ main(int argc, char *argv[])
 
   tree = gtk_ctree_new (2, 0);
   g_signal_connect (G_OBJECT(tree), "tree-select-row",
-		    tree_select_row, NULL);
+		    G_CALLBACK(tree_select_row), NULL);
 
   chatter = gtk_label_new ("");
   gtk_misc_set_alignment (GTK_MISC (chatter), 0.0, 0.5);
@@ -479,7 +478,6 @@ main(int argc, char *argv[])
   load_tasks (root, GTK_CTREE (tree), NULL);
   
   gtk_container_add (GTK_CONTAINER (window), vbox_top);
-  gtk_widget_set_usize (window, window_x, window_y);
 
   g_signal_connect (G_OBJECT (window), "delete-event", 
 		    G_CALLBACK (exit_app), (void *)tree);
